<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kr_KR">
<context>
    <name>AppLauncher</name>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="40"/>
        <source>App Launcher</source>
        <translation>프로그램 런처</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="52"/>
        <source>Choose an app to open the capture</source>
        <translation>캡처를 열 프로그램을 선택</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="56"/>
        <source>Open With</source>
        <translation>다음으로 열기</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="71"/>
        <source>Launch in terminal</source>
        <translation>터미널로 실행</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="72"/>
        <source>Keep open after selection</source>
        <translation>선택한 뒤에도 열어두기</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Unable to launch in terminal.</source>
        <translation>터미널로 실행할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <source>Unable to write in</source>
        <translation>작성할 수 없음</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="92"/>
        <source>Arrow</source>
        <translation>화살표</translation>
    </message>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="104"/>
        <source>Set the Arrow as the paint tool</source>
        <translation>페인트 도구를 화살표로 설정</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <source>Blur</source>
        <translation type="vanished">ぼかし</translation>
    </message>
    <message>
        <source>Set Blur as the paint tool</source>
        <translation type="vanished">ペイントツールとして「ぼかし」をセットする</translation>
    </message>
</context>
<context>
    <name>CaptureLauncher</name>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="65"/>
        <source>&lt;b&gt;Capture Mode&lt;/b&gt;</source>
        <translation>캡처 모드</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="71"/>
        <source>Rectangular Region</source>
        <translation>사각 영역</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="73"/>
        <source>Full Screen (All Monitors)</source>
        <translation>전체화면 (모든 모니터)</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="81"/>
        <source>No Delay</source>
        <translation>지연 없음</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="88"/>
        <source> second</source>
        <translation> 초</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="88"/>
        <source> seconds</source>
        <translation> 초</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="92"/>
        <source>Take new screenshot</source>
        <translation>새로운 스크린샷</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="101"/>
        <source>Area:</source>
        <translation>영역:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="102"/>
        <source>Delay:</source>
        <translation>지연:</translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="97"/>
        <source>Unable to capture screen</source>
        <translation>화면을 캡처할 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="257"/>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation>마우스로 영역을 선택하거나 Esc로 종료합니다.
Enter로 눌러 화면을 캡처합니다.
우클릭으로 색상선택기를 봅니다.
마우스 휠로 사용자 도구의 두께를 바꿉니다.
Space로 사이드 패널을 엽니다.</translation>
    </message>
</context>
<context>
    <name>CircleCountTool</name>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="39"/>
        <source>Circle Counter</source>
        <translation>원형 카운터</translation>
    </message>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="51"/>
        <source>Add an autoincrementing counter bubble</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="40"/>
        <source>Circle</source>
        <translation>원형</translation>
    </message>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="52"/>
        <source>Set the Circle as the paint tool</source>
        <translation>페인트 도구로 원형을 선택</translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="43"/>
        <source>Configuration</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="63"/>
        <source>Interface</source>
        <translation>인터페이스</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="69"/>
        <source>Filename Editor</source>
        <translation>파일명 편집기</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="73"/>
        <source>General</source>
        <translation>일반</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../src/core/controller.cpp" line="202"/>
        <source>&amp;Take Screenshot</source>
        <translation>스크린샷 촬영(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="207"/>
        <source>&amp;Open Launcher</source>
        <translation>런처 열기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="210"/>
        <source>&amp;Configuration</source>
        <translation>설정(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="213"/>
        <source>&amp;Information</source>
        <translation>정보(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="215"/>
        <source>&amp;Quit</source>
        <translation>종료(&amp;Q)</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="41"/>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="53"/>
        <source>Copy the selection into the clipboard</source>
        <translation>선택 영역을 클립보드에 복사</translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <location filename="../../src/utils/dbusutils.cpp" line="52"/>
        <source>Unable to connect via DBus</source>
        <translation>DBus에 접속할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="40"/>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="52"/>
        <source>Leave the capture screen</source>
        <translation>화면 캡쳐를 종료</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="39"/>
        <source>Edit the name of your captures:</source>
        <translation>캡처 파일명 수정:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="43"/>
        <source>Edit:</source>
        <translation>편집:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="45"/>
        <source>Preview:</source>
        <translation>미리보기:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="88"/>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="91"/>
        <source>Saves the pattern</source>
        <translation>패턴을 저장</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="93"/>
        <source>Reset</source>
        <translation>초기화</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="96"/>
        <source>Restores the saved pattern</source>
        <translation>저장된 패턴으로 되돌리기</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="98"/>
        <source>Clear</source>
        <translation>지우기</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="102"/>
        <source>Deletes the name</source>
        <translation>이름을 삭제하다</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="162"/>
        <source>Show help message</source>
        <translation type="unfinished">도움 메세지 보기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="166"/>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation>캡처 모드 시작에 도움 메세지 보기.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="177"/>
        <location filename="../../src/config/geneneralconf.cpp" line="181"/>
        <source>Show desktop notifications</source>
        <translation>데스크톱 알림 사용</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="194"/>
        <source>Show tray icon</source>
        <translation>트레이 아이콘 보기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="198"/>
        <source>Show the systemtray icon</source>
        <translation>시스템 트레이 아이콘 보기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="102"/>
        <location filename="../../src/config/geneneralconf.cpp" line="225"/>
        <source>Import</source>
        <translation>불러오기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="109"/>
        <location filename="../../src/config/geneneralconf.cpp" line="117"/>
        <location filename="../../src/config/geneneralconf.cpp" line="141"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="109"/>
        <source>Unable to read file.</source>
        <translation>파일을 읽을 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="117"/>
        <location filename="../../src/config/geneneralconf.cpp" line="141"/>
        <source>Unable to write file.</source>
        <translation>파일을 작성할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <source>Save File</source>
        <translation>파일을 저장</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="151"/>
        <source>Confirm Reset</source>
        <translation>초기화 확인</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="152"/>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>설정을 초기화해도 괜찮습니까?</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="213"/>
        <source>Configuration File</source>
        <translation>설정 파일</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="218"/>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="232"/>
        <source>Reset</source>
        <translation>초기화</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="243"/>
        <source>Launch at startup</source>
        <translatorcomment>startup의 적절한 번역이 필요합니다.</translatorcomment>
        <translation>컴퓨터를 시작할 때 실행</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="247"/>
        <source>Launch Flameshot</source>
        <translation>Flameshot을 실행</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="257"/>
        <source>Close after capture</source>
        <translation>캡처 후 닫기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="261"/>
        <source>Close after taking a screenshot</source>
        <translation>스크린샷을 찍은 후 닫기</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="273"/>
        <source>Copy URL after upload</source>
        <translation>업로드 이후 URL 복사</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="278"/>
        <source>Copy URL and close window after upload</source>
        <translation>업로드 이후 URL을 복사하고 창 닫기</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="48"/>
        <source>Upload to Imgur</source>
        <translation>Imgur에 업로드</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="55"/>
        <source>Uploading Image</source>
        <translation>이미지를 업로드하는 중</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="156"/>
        <source>Copy URL</source>
        <translation>URL을 복사</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="157"/>
        <source>Open URL</source>
        <translation>URL 열기</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="158"/>
        <source>Delete image</source>
        <translation>이미지를 삭제</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="159"/>
        <source>Image to Clipboard.</source>
        <translation>이미지를 클립보드로.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="184"/>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="200"/>
        <source>Unable to open the URL.</source>
        <translation>URL을 열 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="192"/>
        <source>URL copied to clipboard.</source>
        <translation>URL을 클립보드에 복사했습니다.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="208"/>
        <source>Screenshot copied to clipboard.</source>
        <translation>스크린샷을 클립보드에 복사했습니다.</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="41"/>
        <source>Image Uploader</source>
        <translation>이미지 업로더</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="53"/>
        <source>Upload the selection to Imgur</source>
        <translation>Imgur에 선택영역을 업로드</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="40"/>
        <source>About</source>
        <translation>이 어플리케이션에 대하여</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="62"/>
        <source>SPACEBAR</source>
        <translation>스페이스바</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="63"/>
        <source>Right Click</source>
        <translation>우클릭</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="64"/>
        <source>Mouse Wheel</source>
        <translation>마우스 휠</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="67"/>
        <source>Move selection 1px</source>
        <translation>선택 영역을 1px 이동</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="68"/>
        <source>Resize selection 1px</source>
        <translation>선택 영역을 1px 조정</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="69"/>
        <source>Quit capture</source>
        <translation>캡처를 종료</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="70"/>
        <source>Copy to clipboard</source>
        <translation>클립보드에 복사</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="71"/>
        <source>Save selection as a file</source>
        <translation>선택 영역을 파일로 저장</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="72"/>
        <source>Undo the last modification</source>
        <translation>마지막 변경 되돌리기</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="73"/>
        <source>Toggle visibility of sidebar with options of the selected tool</source>
        <translation>사이드바를 열어 선택한 도구의 옵션보기</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="74"/>
        <source>Show color picker</source>
        <translation>색상 선택기를 표시</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="75"/>
        <source>Change the tool&apos;s thickness</source>
        <translation>도구 두께 변경</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Key</source>
        <translation>키</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="126"/>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;라이센스&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="134"/>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;버전&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="145"/>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;단축키&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="82"/>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>화면 캡처 모드에서 단축키를 사용할 수 있습니다.</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="43"/>
        <source>Line</source>
        <translation>직선</translation>
    </message>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="55"/>
        <source>Set the Line as the paint tool</source>
        <translation>페인트 도구로 직선을 설정</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="43"/>
        <source>Marker</source>
        <translation>마커</translation>
    </message>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="55"/>
        <source>Set the Marker as the paint tool</source>
        <translation>페인트 도구로 마커를 설정</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="40"/>
        <source>Move</source>
        <translation>이동</translation>
    </message>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="52"/>
        <source>Move the selection area</source>
        <translation>선택 영역을 이동</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="34"/>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="46"/>
        <source>Set the Pencil as the paint tool</source>
        <translation>페인트 도구로 연필을 설정</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="40"/>
        <source>Pin Tool</source>
        <translation>고정 도구</translation>
    </message>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="52"/>
        <source>Pin image on the desktop</source>
        <translation>선택 영역을 데스크톱 위에 고정</translation>
    </message>
</context>
<context>
    <name>PixelateTool</name>
    <message>
        <location filename="../../src/tools/blur/blurtool.cpp" line="39"/>
        <source>Pixelate</source>
        <translation>픽셀화</translation>
    </message>
    <message>
        <location filename="../../src/tools/blur/blurtool.cpp" line="51"/>
        <source>Set Pixelate as the paint tool</source>
        <translation>페인트 도구로 픽셀화를 설정</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="93"/>
        <source>Save Error</source>
        <translation>저장 오류</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="48"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="88"/>
        <source>Capture saved as </source>
        <translation>캡처를 저장했습니다:</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="33"/>
        <source>Capture saved to clipboard</source>
        <translation>캡처를 클립보드에 저장했습니다</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="50"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="91"/>
        <source>Error trying to save as </source>
        <translation>저장에 오류가 발생했습니다:</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="82"/>
        <location filename="../../src/main.cpp" line="247"/>
        <location filename="../../src/main.cpp" line="402"/>
        <location filename="../../src/main.cpp" line="429"/>
        <location filename="../../src/main.cpp" line="461"/>
        <source>Unable to connect via DBus</source>
        <translation>DBus에 접속할 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="41"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="42"/>
        <source>Unable to write in</source>
        <translation>작성할 수 없습니다:</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="88"/>
        <source>URL copied to clipboard.</source>
        <translation>URL을 클립보드에 복사했습니다.</translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="52"/>
        <source>Set the Rectangle as the paint tool</source>
        <translation>페인트 도구로 직사각형을 설정</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="40"/>
        <source>Redo</source>
        <translation>되돌리기</translation>
    </message>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="52"/>
        <source>Redo the next modification</source>
        <translation>다음 변경을 되돌리기</translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="41"/>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="53"/>
        <source>Save the capture</source>
        <translation>캡처를 저장</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <location filename="../../src/utils/screengrabber.cpp" line="84"/>
        <source>Unable to capture screen</source>
        <translation>화면을 캡처할 수 없음</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="46"/>
        <source>Rectangular Selection</source>
        <translatorcomment>selection에 대한 적절한 번역이 필요합니다.</translatorcomment>
        <translation>직사각형 Selection</translation>
    </message>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="58"/>
        <source>Set Selection as the paint tool</source>
        <translation>페인트 도구로 직사각형 선택을 설정</translation>
    </message>
</context>
<context>
    <name>SidePanelWidget</name>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="71"/>
        <source>Active thickness:</source>
        <translation>활성 두께:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="72"/>
        <source>Active color:</source>
        <translation>활성 색상:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="217"/>
        <source>Press ESC to cancel</source>
        <translation>ESC를 눌러 취소</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="219"/>
        <source>Grab Color</source>
        <translation>색상 취득</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="40"/>
        <source>Selection Size Indicator</source>
        <translation>선택 크기 표시기</translation>
    </message>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="52"/>
        <source>Show the dimensions of the selection (X Y)</source>
        <translation>선택 범위의 치수 (X Y)를 표시</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="50"/>
        <source>Century (00-99)</source>
        <translation>세기 (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="51"/>
        <source>Year (00-99)</source>
        <translation>년도 (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="52"/>
        <source>Year (2000)</source>
        <translation>년도 (2000)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="53"/>
        <source>Month Name (jan)</source>
        <translation>달 이름 (jan)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="54"/>
        <source>Month Name (january)</source>
        <translation>달 이름 (january)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="55"/>
        <source>Month (01-12)</source>
        <translation>달 (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="56"/>
        <source>Week Day (1-7)</source>
        <translation>주일 (1-7)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="57"/>
        <source>Week (01-53)</source>
        <translation>주 (01-53)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="58"/>
        <source>Day Name (mon)</source>
        <translation>요일 (월)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="59"/>
        <source>Day Name (monday)</source>
        <translation>요일 (월요일)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="60"/>
        <source>Day (01-31)</source>
        <translation>일 (01-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="61"/>
        <source>Day of Month (1-31)</source>
        <translation>일 (1-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="62"/>
        <source>Day (001-366)</source>
        <translation>일 (001-366)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="63"/>
        <source>Time (%H-%M-%S)</source>
        <translation>시각 (%H-%M-%S)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="64"/>
        <source>Time (%H-%M)</source>
        <translation>시각 (%H-%M)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="65"/>
        <source>Hour (00-23)</source>
        <translation>시각 (00-23)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="66"/>
        <source>Hour (01-12)</source>
        <translation>시각 (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="67"/>
        <source>Minute (00-59)</source>
        <translation>분 (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="68"/>
        <source>Second (00-59)</source>
        <translation>초 (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="69"/>
        <source>Full Date (%m/%d/%y)</source>
        <translation>연 월 일 (%m/%d/%y)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="70"/>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>연 월 일 (%Y-%m-%d)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <location filename="../../src/utils/systemnotification.cpp" line="36"/>
        <source>Flameshot Info</source>
        <translation>Flameshot 정보</translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="55"/>
        <source>StrikeOut</source>
        <translation>취소선</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="64"/>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="73"/>
        <source>Bold</source>
        <translation>볼드체</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="82"/>
        <source>Italic</source>
        <translation>이탈릭체</translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="63"/>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="75"/>
        <source>Add text to your capture</source>
        <translation>캡처에 텍스트를 추가</translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="32"/>
        <source>UI Color Editor</source>
        <translation>UI 컬러 편집기</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="107"/>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>선택기를 움직여 색상을 변경하고 미리보기 버튼에서 변경사항을 확인하세요.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="119"/>
        <source>Select a Button to modify it</source>
        <translation>변경 할 버튼 선택</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="129"/>
        <source>Main Color</source>
        <translation>메인 색상</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="133"/>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="144"/>
        <source>Contrast Color</source>
        <translation>대비 색상</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="149"/>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="40"/>
        <source>Undo</source>
        <translation>원상태로 되돌리기</translation>
    </message>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="52"/>
        <source>Undo the last modification</source>
        <translation>마지막 변경을 원상태로 되돌리기</translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="61"/>
        <source>Opacity of area outside selection:</source>
        <translation>선택 영역 외 불투명도:</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="89"/>
        <source>Button Selection</source>
        <translation>버튼 선택</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="95"/>
        <source>Select All</source>
        <translation>모두 선택</translation>
    </message>
</context>
</TS>
